require 'net/http'
require 'json'

module IntelliJ
  module Helpers
    def get_all_releases(edition)
      e_code = node['intellij']['editions'][edition]
      url = node['intellij']['helpers']['releases'] % {
          edition: e_code,
          timestamp: Time.now.getutc
      }
      uri = URI(url)
      response = JSON.parse(Net::HTTP.get(uri))
      releases = response[e_code] || []
      result = {}
      releases.each do |release|
        result[release['version']] = release
      end
      result
    end

    def get_default_version(releases)
      releases.keys[0]
    end

    def get_release_data(version, edition)
      releases = get_all_releases(edition)
      version ||= get_default_version(releases)
      result = releases[version]
      Chef::Application.fatal!("The IntelliJ version #{version} of edition #{edition} could not be found!", 42) unless result
      result
    end

    def get_release_download_info(release)
      os = Chef::Platform.windows? ? 'windowsZip' : 'linux'
      info = release['downloads'][os]
      [info['link'], download_checksum_from_link(info['checksumLink'])]
    end

    def download_checksum_from_link(link)
      uri = URI(link)
      response = Net::HTTP.get(uri)
      response.split(' ').first
    end

    def find_plugin_suggestions(name, edition)
      product = node['intellij']['plugin']['product'][edition]
      url = node['intellij']['plugin']['search'] % { name: name, product: product }
      uri = URI(url)
      response = JSON.parse(Net::HTTP.get(uri))
      result = {}
      response.each do |suggestion|
        name = suggestion['value']
        id = suggestion['data']['url'].match(/\/plugin\/(\d+)-.*/)[1]
        result[name] = {}
        result[name]['id'] = id
        result[name]['name'] = name
        result[name]['family'] = suggestion['data']['target']
      end
      result
    end

    def find_plugin_updates(id, family)
      url = node['intellij']['plugin']['updates'] % { id: id }
      uri = URI(url)
      response = JSON.parse(Net::HTTP.get(uri))
      result = {}
      response['updates'].each do |update|
        link = node['intellij']['plugin']['download_link'] % {
            file: update['file'],
            update_id: update['id'],
            plugin_id: id,
            family: family
        }
        result[update['id']] = link
      end
      result
    end


    def detect_vcs(path)
      vcs_type = nil
      if ::File.exist?("#{path}/.git")
        vcs_type = :Git
      end
      vcs_type
    end

    def create_missing_component(name, file, fragment = nil)
      xml_edit "Make sure the #{name} component exists" do
        path file
        parent '/project'
        target "/project/component[@name=\"#{name}\"]"
        fragment "<component name=\"#{name}\">#{fragment}</component>"
        action :append_if_missing
        not_if { ::File.read(file).match(/<component.*name="#{name}".*>/) }
      end
    end
  end
end
