require 'nokogiri'

module IntelliJ
  module Workspace
    module Artifact
      def build_xml(name, type, output_path, root, project_path)
        filename = generate_artifact_filename(name)
        output_path ||= "$PROJECT_DIR$/out/artifacts/#{filename}"
        relative_output = output_path.gsub(project_path, '$PROJECT_DIR$')

        <<-EOH
          <component name="ArtifactManager">
            <artifact type="#{type}" name="#{name}">
              <output-path>#{relative_output}</output-path>
              #{root}
            </artifact>
          </component>
        EOH
      end

      def create_artifact(project_path, artifact_name, xml, user, group)
        repo = format(node['intellij']['artifact']['repository'], path: project_path)
        filename = generate_artifact_filename(artifact_name)

        directory repo do
          recursive true
          user user
          group group
        end

        file 'Update artifact configuration' do
          content Nokogiri::XML(xml, &:noblanks).root.to_xml(indent: 2)
          path "#{repo}/#{filename}.xml"
          user user
          group group
        end
      end

      def delete_artifact(project_path, artifact_name)
        repo = format(node['intellij']['artifact']['repository'], path: project_path)
        filename = generate_artifact_filename(artifact_name)

        file "#{repo}/#{filename}.xml" do
          action :delete
        end
      end

      def generate_artifact_filename(artifact_name)
        splits = artifact_name.split(/[\s\-:.]/)
        splits.join('_')
      end
    end
  end
end
