include IntelliJ::Helpers

module IntelliJ
  module Module
    def create_module(resource)
      module_file = generate_module_file_path(resource.path, resource.module_name)

      directory resource.path do
        recursive true
        user resource.user
        group resource.group
      end

      variables = {
        IS_MAVEN: maven_module?(resource.path),
        SDK_NAME: resource.sdk_name,
        SDK_TYPE: resource.sdk_type,
        TYPE: resource.type,
      }

      template 'Create base module file' do
        source 'module/main.iml.erb'
        path module_file
        not_if { ::File.exist?(module_file) }
        user resource.user
        group resource.group
        variables variables
      end

      module_file
    end

    def delete_module_file(path, name)
      module_file = generate_module_file_path(path, name)
      file module_file do
        action :delete
      end
      module_file
    end

    def add_module_to_project(project_path, module_file, user, group)
      file = format(node['intellij']['project']['config']['modules'], path: project_path)

      directory ::File.dirname(file) do
        recursive true
        user user
        group group
      end

      template 'Create default modules file in case it does not exist' do
        source 'project/modules.xml'
        path file
        not_if { ::File.exist?(file) }
        user user
        group group
      end

      relative_module = module_file.gsub(project_path, '$PROJECT_DIR$')

      xml_edit 'Add module to project' do
        path file
        parent '/project/component[@name="ProjectModuleManager"]/modules'
        target "/project/component[@name=\"ProjectModuleManager\"]/modules/module[@filepath=\"#{relative_module}\"]"
        fragment "<module fileurl=\"file://#{relative_module}\" filepath=\"#{relative_module}\" />"
        action :append_if_missing
      end
    end

    def delete_module_from_project(project_path, module_file)
      file = format(node['intellij']['project']['config']['modules'], path: project_path)
      relative_module = module_file.gsub(project_path, '$PROJECT_DIR$')

      xml_edit file do
        target "/project/component[@name=\"ProjectModuleManager\"]/modules/module[@filepath=\"#{relative_module}\"]"
        action :remove
        only_if { ::File.exist?(file) }
      end
    end

    def detect_module_vcs(path, project_path, user, group)
      file = format(node['intellij']['project']['config']['vcs'], path: project_path)
      vcs_type = detect_vcs(path)

      directory ::File.dirname(file) do
        recursive true
        user user
        group group
      end

      template 'Create default modules file in case it does not exist' do
        source 'project/vcs.xml'
        path file
        not_if { ::File.exist?(file) }
        user user
        group group
        only_if { vcs_type }
      end

      relative_module = path.gsub(project_path, '$PROJECT_DIR$')

      xml_edit 'Add module to project' do
        path file
        parent '/project/component[@name="VcsDirectoryMappings"]'
        target "/project/component[@name=\"VcsDirectoryMappings\"]/mapping[@directory=\"#{relative_module}\"]"
        fragment "<mapping directory=\"#{relative_module}\" vcs=\"#{vcs_type}\" />"
        only_if { vcs_type }
        action :append_if_missing
      end
    end

    def delete_module_from_vcs(path, project_path)
      file = format(node['intellij']['project']['config']['vcs'], path: project_path)
      relative_module = path.gsub(project_path, '$PROJECT_DIR$')

      xml_edit file do
        target "/project/component[@name=\"VcsDirectoryMappings\"]/mapping[@directory=\"#{relative_module}\"]"
        only_if { ::File.exist?(file) }
        action :remove
      end
    end

    def detect_maven_module(path, project_path, user, group)
      file = format(node['intellij']['project']['config']['misc'], path: project_path)

      directory ::File.dirname(file) do
        recursive true
        user user
        group group
      end

      template 'Create default misc file in case it does not exist' do
        source 'project/misc.xml'
        path file
        not_if { ::File.exist?(file) }
        only_if { maven_module?(path) }
        user user
        group group
      end

      create_missing_component('MavenProjectsManager', file, '<option name="originalFiles"><list></list></option>') if maven_module?(path)
      relative_pom = "#{path}/pom.xml".gsub(project_path, '$PROJECT_DIR$')

      xml_edit 'Add Maven module to project' do
        path file
        parent '/project/component[@name="MavenProjectsManager"]'
        target "/project/component[@name=\"MavenProjectsManager\"]/option/list/option[@value=\"#{relative_pom}\"]"
        fragment "<option value=\"#{relative_pom}\" />"
        only_if { maven_module?(path) }
        action :append_if_missing
      end
    end

    def delete_module_from_maven(path, project_path)
      file = format(node['intellij']['project']['config']['misc'], path: project_path)
      relative_pom = "#{path}/pom.xml".gsub(project_path, '$PROJECT_DIR$')

      xml_edit file do
        target "/project/component[@name=\"MavenProjectsManager\"]/option/list/option[@value=\"#{relative_pom}\"]"
        only_if { ::File.exist?(file) }
        action :remove
      end
    end

    def delete_content(path)
      directory path do
        action :delete
        recursive true
        only_if { ::File.exist?(path) }
      end
    end

    def maven_module?(path)
      ::File.exist?("#{path}/pom.xml")
    end

    def generate_module_file_path(path, name)
      name ||= ::File.basename(path)
      "#{path}/#{name}.iml"
    end
  end
end
