include IntelliJ::Helpers

module IntelliJ
  module Plugins
    def get_default_source(name, edition, update)
      plugin = find_plugin(name, edition)
      get_download_link(plugin, update)
    end

    def find_plugin(name, edition)
      suggestions = find_plugin_suggestions(name, edition)
      Chef::Application.fatal!("The plugin #{name} for #{edition} edition could not be found! Similar plugins: #{suggestions.keys}", 42) unless suggestions[name]
      suggestions[name]
    end

    def get_download_link(plugin, update)
      updates = find_plugin_updates(plugin['id'], plugin['family'])
      update ||= updates.keys[0]
      Chef::Application.fatal!("The plugin #{plugin['name']} does not have update #{update}! Possible updates: #{updates.keys}", 42) unless updates[update.to_i]
      updates[update.to_i]
    end

    def install_plugin(source, workspace, user, group)
      repo = format(node['intellij']['plugin']['local_repository'], workspace: workspace)
      path = "#{repo}/#{::File.basename(URI.parse(source).path)}"

      directory 'Make sure local repository for plugins exists' do
        path repo
        recursive true
        user user
        group group
      end

      remote_file 'Download the plugin' do
        source source
        path path
        user user
        group group
      end

      zipfile path do
        into repo
        overwrite true
        only_if { ::File.extname(path) == '.zip' }
      end

      file 'Remove remaining zip file' do
        path path
        action :delete
        only_if { ::File.extname(path) == '.zip' }
      end
    end
  end
end
