module IntelliJ
  module Project
    def create_project(path, user, group)
      directory 'Make sure the project path exsists' do
        path path
        recursive true
        user user
        group group
      end

      directory 'Make sure the configuration directory exists' do
        path format(node['intellij']['project']['config_dir'], path: path)
        recursive true
        user user
        group group
      end
    end

    def configure_project_name(path, name, user, group)
      file_path = format(node['intellij']['project']['config']['project_name'], path: path)

      file file_path do
        content name
        user user
        group group
      end
    end

    def configure_default_sdk(resource)
      file = format(node['intellij']['project']['config']['misc'], path: resource.path)

      directory ::File.dirname(file) do
        recursive true
        user resource.user
        group resource.group
      end

      template 'Create default misc file in case it does not exist' do
        source 'project/misc.xml'
        path file
        user resource.user
        group resource.group
        not_if { ::File.exist?(file) }
      end

      xml_edit 'Configure default SDK and language level' do
        path file
        parent '/project'
        target '/project/component[@name="ProjectRootManager"]'
        fragment get_default_sdk_fragment(resource.default_sdk_name, resource.default_sdk_type, resource.language_level)
        action :append_if_missing
      end
    end

    def get_default_sdk_fragment(sdk_name, sdk_type, lang_level)
      result = "<component name=\"ProjectRootManager\" version=\"2\" languageLevel=\"#{lang_level}\" default=\"false\"/>"
      if sdk_name
        result = case sdk_type
                 when :JavaSDK
                   <<-EOH
                      <component name="ProjectRootManager" version="2" languageLevel="#{lang_level}" default="false" project-jdk-name="#{sdk_name}" project-jdk-type="JavaSDK">
                        <output url="file://$PROJECT_DIR$/out" />
                      </component>
                   EOH
                 else
                   "<component name=\"ProjectRootManager\" version=\"2\" languageLevel=\"#{lang_level}\" default=\"false\" project-jdk-name=\"#{sdk_name}\" project-jdk-type=\"#{sdk_type}\" />"
                 end
      end
      result
    end
  end
end
