include IntelliJ::Helpers

module IntelliJ
  module Workspace
    module RunConfiguration
      def generate_xml(resource)
        <<-EOH
          <configuration name="#{resource.name}" type="#{resource.type}" factoryName="#{resource.factory}"
            #{resource.folder ? "folderName=\"#{resource.folder}\"" : ''}>
            #{resource.body}
          </configuration>
        EOH
      end

      def save_run_configuration(xml, name, project_path, user, group)
        file = format(node['intellij']['project']['config']['workspace'], path: project_path)

        directory ::File.dirname(file) do
          recursive true
          user user
          group group
        end

        template 'Create default file if it does not exist' do
          source 'project/workspace.xml'
          path file
          cookbook 'intellij'
          user user
          group group
          not_if { ::File.exist?(file) }
        end

        create_missing_component('RunManager', file)

        xml_edit "Add the #{name} SDK to IntelliJ" do
          path file
          parent '/project/component[@name="RunManager"]'
          target "/project/component[@name=\"RunManager\"]/configuration[@name=\"#{name}\"]"
          fragment xml
          action :append_if_missing
        end
      end

      def remove_run_configuration(name, project_path)
        file = format(node['intellij']['project']['config']['workspace'], path: project_path)

        xml_edit "Add the #{name} SDK to IntelliJ" do
          path file
          target "/project/component[@name=\"RunManager\"]/configuration[@name=\"#{name}\"]"
          action :remove
          only_if { ::File.exist?(file) }
        end
      end
    end
  end
end
