module IntelliJ
  module Workspace
    module Sdk
      def add_sdk(resource)
        file = format(node['intellij']['workspace']['config']['sdk'], path: resource.workspace)

        directory 'Make sure the parent directory exists' do
          path File.dirname(file)
          recursive true
          user resource.user
          group resource.group
        end

        template 'Make empty file for SDK settings' do
          not_if { ::File.exist?(file) }
          source 'workspace/jdk.table.xml'
          path file
          user resource.user
          group resource.group
          cookbook 'intellij'
        end

        roots_config = format(node['intellij']['sdk']['roots'][resource.type], path: resource.path)

        xml_edit "Add the #{resource.name} SDK to IntelliJ" do
          path file
          parent '/application/component[@name="ProjectJdkTable"]'
          target "/application/component[@name=\"ProjectJdkTable\"]/jdk[name/@value=\"#{resource.name}\"]"
          fragment <<-EOH
            <jdk version="2">
                <name value="#{resource.name}" />
                <type value="#{resource.type}" />
                <homePath value="#{resource.path}" />
                #{roots_config}
            </jdk>
          EOH
          action :append_if_missing
        end
      end

      def delete_sdk(workspace, name)
        file = format(node['intellij']['workspace']['config']['sdk'], path: workspace)

        xml_edit "Remove the #{name} SDK from the IntelliJ" do
          path file
          target "/application/component[@name=\"ProjectJdkTable\"]/jdk[name/@value=\"#{name}\"]"
          action :remove
          only_if { ::File.exist?(file) }
        end
      end
    end
  end
end
