include IntelliJ::Install

action :install do
  begin
    source, checksum, version = summarize_release(@new_resource)
    path = @new_resource.path
    edition = @new_resource.edition
    user = @new_resource.user
    group = @new_resource.group

    ruby_block 'Start the IntelliJ installation' do
      block do
        package_path = download_package(source, checksum, user, group)
        install_package(path, package_path, user, group)
      end
      not_if { intellij_installed?(path, version, edition) }
    end
  end
end

action :update do
  begin
    source, checksum, version = summarize_release(@new_resource)
    path = @new_resource.path
    edition = @new_resource.edition
    user = @new_resource.user
    group = @new_resource.group

    ruby_block 'Install IntelliJ or update it if it\'s different version' do
      block do
        local_version, local_edition = get_local_intellij_info(path)
        if local_version != version || local_edition != node['intellij']['edition_code'][edition]
          remove_package(path)
          package_path = download_package(source, checksum, user, group)
          install_package(path, package_path, user, group)
        else
          Chef::Log.info("The IntelliJ #{edition} edition in #{path} is already installed in #{version} version")
        end
      end
    end
  end
end

action :delete do
  begin
    Chef::Application.fatal!('You must pass either source or version parameter in order to remove IntelliJ!', 42) if !@new_resource.path && !@new_resource.version
    remove_package(@new_resource.path)
  end
end
