#
# This recipe is only an example for configuring IntelliJ.
# It will install the latest version of IntelliJ Community Edition, then will configure new workspace (which is great way
# to separate different configurations like plugins, SDKs etc.), add project, modules and their configurations
# Please note that this recipe DOES NOT install Git/Maven/Java etc. This cookbook only manages the IntelliJ installation
# and hence expects all those to be installed in the first place.
#

group 'group'

user 'user' do
  group 'group'
end

intellij '/home/chef/IntelliJ' do
  edition :community
  action :update
  user 'user'
  group 'group'
end

intellij_workspace '/home/chef/workspace' do
  default_project '/home/chef/workspace/project'
  intellij_path '/home/chef/IntelliJ'
  color_scheme :Darcula
  action :create
  user 'user'
  group 'group'
end

intellij_plugin 'Batch Scripts Support' do
  workspace '/home/chef/workspace'
  edition :community
  action :install
  user 'user'
  group 'group'
end

# We assume that this JDK is already installed in the system - this cookbook does not manage JDK itself
intellij_sdk 'JDK 10.0' do
  workspace '/home/chef/workspace'
  path '/usr/local/jdk10.0.2/bin/java'
  type :JavaSDK
  action :add
  user 'user'
  group 'group'
end

intellij_project '/home/chef/workspace/project' do
  project_name 'My fantastic project'
  default_sdk_name 'JDK 10.0'
  default_sdk_type :JavaSDK
  action :create
  user 'user'
  group 'group'
end

intellij_module '/home/chef/workspace/project/Module1' do
  project_path '/home/chef/workspace/project'
  module_name 'Created new module'
  action :create
  user 'user'
  group 'group'
end

# Creating example of Run configuration
# We will just use nice batch plugin we installed before
file '/home/chef/workspace/project/example.sh' do
  content <<-EOH
    #!/bin/bash
    echo "Our script got parameter: ${1}"
  EOH
  mode '0755'
  user 'user'
  group 'group'
  action :create
end

intellij_run_configuration 'Start simple batch script' do
  project_path '/home/chef/workspace/project'
  type 'BatchConfigurationType'
  factory 'Batch'
  body <<-EOH
    <option name="INTERPRETER_OPTIONS" value="" />
    <option name="WORKING_DIRECTORY" value="$PROJECT_DIR$" />
    <option name="PARENT_ENVS" value="true" />
    <module name="" />
    <option name="SCRIPT_NAME" value="$PROJECT_DIR$/example.sh" />
    <option name="PARAMETERS" value="Hello" />
    <method v="2" />
  EOH
  action :create
  user 'user'
  group 'group'
end
