#
# This recipe is only an example for configuring IntelliJ.
# It will install the latest version of IntelliJ Community Edition, then will configure new workspace (which is great way
# to separate different configurations like plugins, SDKs etc.), add project, modules and their configurations
# Please note that this recipe DOES NOT install Git/Maven/Java etc. This cookbook only manages the IntelliJ installation
# and hence expects all those to be installed in the first place.
#

intellij 'C:/Program Files/JetBrains/IntelliJ' do
  edition :community
  action :update
end

intellij_workspace 'C:/Test/Workspace' do
  default_project 'C:/Test/Workspace/My Project'
  intellij_path 'C:/Program Files/JetBrains/IntelliJ'
  color_scheme :Darcula
  action :create
end

intellij_plugin 'Batch Scripts Support' do
  workspace 'C:/Test/Workspace'
  edition :community
  action :install
end

# We assume that this JDK is already installed in the system - this cookbook does not manage JDK itself
intellij_sdk 'JDK 10.0' do
  workspace 'C:/Test/Workspace'
  path 'C:/Program Files/Java/jdk-10.0.2'
  type :JavaSDK
  action :add
end

intellij_project 'C:/Test/Workspace/My Project' do
  project_name 'My fantastic project'
  default_sdk_name 'JDK 10.0'
  default_sdk_type :JavaSDK
  action :create
end

intellij_module 'C:/Test/Workspace/My Project/Module1' do
  project_path 'C:/Test/Workspace/My Project'
  module_name 'Created new module'
  action :create
end

# Creating sample Maven project with simple HelloWorld Java class
# We assume that it is already existing and we just want to load it into the IntelliJ project
# We will also assume that this module is taken from Git
directory 'C:/Test/Workspace/My Project/Module2/.git' do
  recursive true
  action :create
end

file 'C:/Test/Workspace/My Project/Module2/pom.xml' do
  content <<-EOH
<?xml version="1.0" encoding="UTF-8"?>
<project xmlns="http://maven.apache.org/POM/4.0.0"
         xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
         xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/xsd/maven-4.0.0.xsd">
    <modelVersion>4.0.0</modelVersion>

    <groupId>org.thedeem.sample</groupId>
    <artifactId>sample-maven-module</artifactId>
    <version>1.0-SNAPSHOT</version>
    <packaging>jar</packaging>
    <properties>
       <maven.compiler.source>1.8</maven.compiler.source>
       <maven.compiler.target>1.8</maven.compiler.target>
    </properties>
    <dependencies>
    </dependencies>
</project>
  EOH
  action :create
end

directory 'C:/Test/Workspace/My Project/Module2/src/main/java/org.thedeem.sample' do
  recursive true
  action :create
end

file 'C:/Test/Workspace/My Project/Module2/src/main/java/org.thedeem.sample/HelloWorld.java' do
  content <<-EOH
package org.thedeem.sample;

public class HelloWorld {
    public static void main(String[] args) {
        System.out.println("Hello, World");
    }
}
  EOH
  action :create
end

intellij_module 'C:/Test/Workspace/My Project/Module2' do
  project_path 'C:/Test/Workspace/My Project'
  type :JAVA_MODULE
  module_name 'sample-maven-module'
  sdk_name 'JDK 10.0'
  sdk_type :JavaSDK
  action :create
end

intellij_run_configuration 'Clean install Maven module' do
  project_path 'C:/Test/Workspace/My Project'
  type 'MavenRunConfiguration'
  factory 'Maven'
  folder 'Java Application'
  body <<-EOH
    <MavenSettings>
      <option name="myGeneralSettings" />
      <option name="myRunnerSettings" />
      <option name="myRunnerParameters">
        <MavenRunnerParameters>
          <option name="profiles">
            <set />
          </option>
          <option name="goals">
            <list>
              <option value="clean" />
              <option value="install" />
            </list>
          </option>
          <option name="pomFileName" />
          <option name="profilesMap">
            <map />
          </option>
          <option name="resolveToWorkspace" value="false" />
          <option name="workingDirPath" value="$PROJECT_DIR$/Module2" />
        </MavenRunnerParameters>
      </option>
    </MavenSettings>
    <method v="2" />
  EOH
  action :create
end

intellij_run_configuration 'HelloWorld from Java' do
  project_path 'C:/Test/Workspace/My Project'
  type 'Application'
  factory 'Application'
  folder 'Java Application'
  body <<-EOH
    <option name="MAIN_CLASS_NAME" value="org.thedeem.sample.HelloWorld" />
    <module name="sample-maven-module" />
    <method v="2">
      <option name="Make" enabled="true" />
    </method>
  EOH
  action :create
end

# Creating example of Run configuration
# We will just use nice batch plugin we installed before
file 'C:/Test/Workspace/My Project/example.bat' do
  content <<-EOH
    @echo off
    SET PARAMETER=%1
    echo "Our script got parameter: %PARAMETER%"
  EOH
  action :create
end

intellij_run_configuration 'Start simple batch script' do
  project_path 'C:/Test/Workspace/My Project'
  type 'BatchConfigurationType'
  factory 'Batch'
  body <<-EOH
    <option name="INTERPRETER_OPTIONS" value="" />
    <option name="WORKING_DIRECTORY" value="$PROJECT_DIR$" />
    <option name="PARENT_ENVS" value="true" />
    <module name="" />
    <option name="SCRIPT_NAME" value="$PROJECT_DIR$/example.bat" />
    <option name="PARAMETERS" value="Hello" />
    <method v="2" />
  EOH
  action :create
end

intellij_artifact 'sample-maven-module:jar' do
  project_path 'C:/Test/Workspace/My Project'
  type 'jar'
  root <<-EOH
    <root id="archive" name="sample-maven-module.jar">
      <element id="module-output" name="sample-maven-module" />
    </root>
  EOH
  action :create
end
